install_process_db_telemetry

Function install_process_db_telemetry 

pub fn install_process_db_telemetry(telemetry: DbTelemetryHandle) -> bool
Install the process-wide SQLite telemetry sink.

Startup owners should call this once after OTEL initialization. Low-level database paths will use the registered sink unless an explicit sink is provided. Subsequent installs are ignored and keep the first installed sink.