pub struct ExtractionOutcome {
pub metadata: ThreadMetadata,
pub memory_mode: Option<String>,
pub parse_errors: usize,
}Expand description
The outcome of extracting metadata from a rollout.
Fields
metadata: ThreadMetadataThe extracted thread metadata.
memory_mode: Option<String>The explicit thread memory mode from rollout metadata, if present.
parse_errors: usizeThe number of rollout lines that failed to parse.