pub struct RuntimeDbBackup {
pub original_path: PathBuf,
pub backup_path: PathBuf,
}Fields
original_path: PathBufPath where the runtime database or sidecar lived before it was moved.
backup_path: PathBufPath where the runtime database or sidecar was backed up.