pub struct ThreadsPage {
pub items: Vec<ThreadMetadata>,
pub parent_thread_ids: HashMap<ThreadId, ThreadId>,
pub next_anchor: Option<Anchor>,
pub num_scanned_rows: usize,
}Expand description
A single page of thread metadata results.
Fields
items: Vec<ThreadMetadata>The thread metadata items in this page.
parent_thread_ids: HashMap<ThreadId, ThreadId>Immediate parents for page items found through the persisted spawn graph.
next_anchor: Option<Anchor>The next anchor to use for pagination, if any.
num_scanned_rows: usizeThe number of rows scanned to produce this page.