pub fn install_process_db_telemetry(telemetry: DbTelemetryHandle) -> boolExpand description
Install the process-wide SQLite telemetry sink.
Startup owners should call this once after OTEL initialization. Low-level database paths will use the registered sink unless an explicit sink is provided. Subsequent installs are ignored and keep the first installed sink.